@@ -29,8 +29,15 @@ class InitBase:
 
     @classmethod
     def from_dict(cls, dic):
-        df = {k: v for k, v in dic.items()}
-        return cls(**df)
+        """
+
+        Args:
+            dic:
+
+        Returns:
+
+        """
+        return cls(**dic)
 
     def export(self):
         """
@@ -46,6 +53,10 @@ class InitBase:
         :return:
         """
 
+    @staticmethod
+    def stringer(value) -> str:
+        return str(value) if value else str()
+
 
 class DBBase:
     """Common methods and attributes for basic models"""
